@@ -1240,10 +1240,10 @@ advanced_backlight_plugin_770_update_brightness_value (AdvancedBacklightPluginPr
 
   FILE* myfile = fopen ("/sys/devices/platform/omapfb/panel/backlight_level", "w");
 
-  if (myfile != NULL)
+  if (myfile != NULL) {
     fprintf(myfile, "%d\n", value);
-
-  fclose(myfile);
+    fclose(myfile);
+  }
 }
 
 /*
